==> foundry_platform_sdk-0.49.0.tar.gz: foundry_platform_sdk-0.49.0/foundry/v1/ontologies/errors/_object_not_found.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Dict
from typing import Literal

import pydantic
from typing_extensions import NotRequired
from typing_extensions import TypedDict

from foundry._errors import PalantirRPCException
from foundry.v1.ontologies.models._object_type_api_name import ObjectTypeApiName
from foundry.v1.ontologies.models._primary_key_value import PrimaryKeyValue
from foundry.v1.ontologies.models._property_api_name import PropertyApiName


class ObjectNotFoundParameters(TypedDict):
    """The requested object is not found, or the client token does not have access to it."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    objectType: NotRequired[ObjectTypeApiName]

    primaryKey: Dict[PropertyApiName, PrimaryKeyValue]


@dataclass
class ObjectNotFound(PalantirRPCException):
    name: Literal["ObjectNotFound"]
    parameters: ObjectNotFoundParameters
    error_instance_id: str


__all__ = ["ObjectNotFound"]

==> foundry_platform_sdk-0.95.0.tar.gz: foundry_platform_sdk-0.95.0/foundry/v1/ontologies/errors/_object_not_found.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Dict
from typing import Literal

from typing_extensions import NotRequired
from typing_extensions import TypedDict

from foundry._errors import NotFoundError
from foundry.v1.ontologies.models._object_type_api_name import ObjectTypeApiName
from foundry.v1.ontologies.models._primary_key_value import PrimaryKeyValue
from foundry.v1.ontologies.models._property_api_name import PropertyApiName


class ObjectNotFoundParameters(TypedDict):
    """The requested object is not found, or the client token does not have access to it."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    objectType: NotRequired[ObjectTypeApiName]

    primaryKey: Dict[PropertyApiName, PrimaryKeyValue]


@dataclass
class ObjectNotFound(NotFoundError):
    name: Literal["ObjectNotFound"]
    parameters: ObjectNotFoundParameters
    error_instance_id: str


__all__ = ["ObjectNotFound"]
